@@ -10,7 +10,7 @@ import os
 from os.path import abspath, dirname
 
 # Project must be built+installed to generate docs
-import commands1
+import commands2
 
 # -- RTD configuration ------------------------------------------------
 
@@ -46,20 +46,34 @@ source_suffix = ".rst"
 master_doc = "index"
 
 # General information about the project.
-project = "RobotPy Commands v1"
-copyright = "2020, RobotPy development team"
+project = "RobotPy Commands v2"
+copyright = "2021, RobotPy development team"
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
 # built documents.
 #
 # The short X.Y version.
-version = ".".join(commands1.__version__.split(".")[:2])
+version = ".".join(commands2.__version__.split(".")[:2])
 # The full version, including alpha/beta/rc tags.
-release = commands1.__version__
+release = commands2.__version__
 
 autoclass_content = "both"
 
+intersphinx_mapping = {
+    "networktables": (
+        f"https://robotpy.readthedocs.io/projects/pynetworktables/en/{rtd_version}/",
+        None,
+    ),
+    "wpilib": (
+        f"https://robotpy.readthedocs.io/projects/wpilib/en/{rtd_version}/",
+        None,
+    ),
+    "wpimath": (
+        f"https://robotpy.readthedocs.io/projects/wpimath/en/{rtd_version}/",
+        None,
+    ),
+}
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
@@ -92,8 +106,8 @@ latex_elements = {}
 latex_documents = [
     (
         "index",
-        "RobotPyCommandV1Doc.tex",
-        "RobotPy CommandV1 Documentation",
+        "RobotPyCommandV2Doc.tex",
+        "RobotPy CommandV2 Documentation",
         "RobotPy development team",
         "manual",
     )
@@ -107,10 +121,10 @@ latex_documents = [
 texinfo_documents = [
     (
         "index",
-        "RobotPyCommandV1Doc",
-        "RobotPy CommandV1 Documentation",
+        "RobotPyCommandV2Doc",
+        "RobotPy CommandV2 Documentation",
         "RobotPy development team",
-        "RobotPyCommandV1Doc",
+        "RobotPyCommandV2Doc",
         "One line description of project.",
         "Miscellaneous",
     )
@@ -119,10 +133,10 @@ texinfo_documents = [
 # -- Options for Epub output ----------------------------------------------
 
 # Bibliographic Dublin Core info.
-epub_title = "RobotPy CommandV1"
+epub_title = "RobotPy CommandV2"
 epub_author = "RobotPy development team"
 epub_publisher = "RobotPy development team"
-epub_copyright = "2020, RobotPy development team"
+epub_copyright = "2021, RobotPy development team"
 
 # A list of files that should not be packed into the epub file.
 epub_exclude_files = ["search.html"]
@@ -134,11 +148,11 @@ from robotpy_sphinx.sidebar import generate_sidebar
 
 generate_sidebar(
     globals(),
-    "commandv1",
+    "commandv2",
     "https://raw.githubusercontent.com/robotpy/docs-sidebar/master/sidebar.toml",
 )
 
 root = abspath(dirname(__file__))
 
-gen_package(root, "commands1")
-gen_package(root, "commands1.buttons")
+gen_package(root, "commands2")
+gen_package(root, "commands2.button")
